==> zego_uikit-2.11.0.tar.gz: lib/src/services/media_service.dart <==
part of 'uikit_service.dart';

/// @nodoc
mixin ZegoMediaService {
  /// Start playing.
  Future<MediaPlayResult> playMedia({
    required String filePathOrURL,
    bool enableRepeat = false,
    bool autoStart = true,
  }) async {
    return ZegoUIKitCore.shared.playMedia(
      filePathOrURL: filePathOrURL,
      enableRepeat: enableRepeat,
      autoStart: autoStart,
    );
  }

  /// Start playing.
  Future<void> startMedia() async {
    return ZegoUIKitCore.shared.startMedia();
  }

  /// Stop playing.
  Future<void> stopMedia() async {
    return ZegoUIKitCore.shared.stopMedia();
  }

  /// Pause playing.
  Future<void> pauseMedia() async {
    return ZegoUIKitCore.shared.pauseMedia();
  }

  /// Resume playing.
  Future<void> resumeMedia() async {
    return ZegoUIKitCore.shared.resumeMedia();
  }

  /// Set the specified playback progress, Unit is millisecond.
  ///
  /// - [millisecond] Point in time of specified playback progress
  Future<MediaSeekToResult> seekTo(int millisecond) async {
    return ZegoUIKitCore.shared.mediaSeekTo(millisecond);
  }

  /// Set media player volume. Both the local play volume and the publish volume are set.
  ///
  /// - [volume] The range is 0 ~ 100. The default is 30.
  Future<void> setMediaVolume(int volume) async {
    return ZegoUIKitCore.shared.setMediaVolume(volume);
  }

  int getMediaVolume() {
    return ZegoUIKitCore.shared.getMediaVolume();
  }

  Future<void> muteMediaLocal(bool mute) async {
    ZegoUIKitCore.shared.muteMediaLocal(mute);
  }

  ValueNotifier<bool> getMediaMuteNotifier() {
    return ZegoUIKitCore.shared.getMediaMuteNotifier();
  }

  ValueNotifier<int> getMediaVolumeNotifier() {
    return ZegoUIKitCore.shared.getMediaVolumeNotifier();
  }

  /// Get the total progress of your media resources, Returns Unit is millisecond.
  int getMediaTotalDuration() {
    return ZegoUIKitCore.shared.getMediaTotalDuration();
  }

  /// Get current playing progress.
  int getMediaCurrentProgress() {
    return ZegoUIKitCore.shared.getMediaCurrentProgress();
  }

  ValueNotifier<int> getMediaCurrentProgressNotifier() {
    return ZegoUIKitCore.shared.getMediaCurrentProgressNotifier();
  }

  MediaType getMediaType() {
    return ZegoUIKitCore.shared.getMediaType();
  }

  ValueNotifier<MediaType> getMediaTypeNotifier() {
    return ZegoUIKitCore.shared.getMediaTypeNotifier();
  }

  ValueNotifier<MediaPlayState> getMediaPlayStateNotifier() {
    return ZegoUIKitCore.shared.getMediaPlayStateNotifier();
  }

  Future<List<PlatformFile>> pickPureAudioMediaFile() async {
    return ZegoUIKitCore.shared.pickPureAudioMediaFile();
  }

  Future<List<PlatformFile>> pickVideoMediaFile() async {
    return ZegoUIKitCore.shared.pickVideoMediaFile();
  }

  Future<List<PlatformFile>> pickMediaFile() async {
    return ZegoUIKitCore.shared.pickMediaFile();
  }

  MediaInfo getMediaInfo() {
    return ZegoUIKitCore.shared.getMediaInfo();
  }
}

==> zego_uikit-2.14.0.tar.gz: lib/src/services/media_service.dart <==
part of 'uikit_service.dart';

/// @nodoc
mixin ZegoMediaService {
  /// Start playing.
  Future<MediaPlayResult> playMedia({
    required String filePathOrURL,
    bool enableRepeat = false,
    bool autoStart = true,
  }) async {
    final playResult = await ZegoUIKitCore.shared.playMedia(
      filePathOrURL: filePathOrURL,
      enableRepeat: enableRepeat,
      autoStart: autoStart,
    );

    if (ZegoUIKitErrorCode.success != playResult.errorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl.add(ZegoUIKitError(
        code: ZegoUIKitErrorCode.mediaPlayError,
        message: playResult.message,
        method: 'playMedia',
      ));
    }

    return playResult;
  }

  /// Start playing.
  Future<void> startMedia() async {
    return ZegoUIKitCore.shared.startMedia();
  }

  /// Stop playing.
  Future<void> stopMedia() async {
    return ZegoUIKitCore.shared.stopMedia();
  }

  /// Pause playing.
  Future<void> pauseMedia() async {
    return ZegoUIKitCore.shared.pauseMedia();
  }

  /// Resume playing.
  Future<void> resumeMedia() async {
    return ZegoUIKitCore.shared.resumeMedia();
  }

  /// Set the specified playback progress, Unit is millisecond.
  ///
  /// - [millisecond] Point in time of specified playback progress
  Future<MediaSeekToResult> seekTo(int millisecond) async {
    final seekResult = await ZegoUIKitCore.shared.mediaSeekTo(millisecond);

    if (ZegoErrorCode.CommonSuccess != seekResult.errorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl.add(ZegoUIKitError(
        code: ZegoUIKitErrorCode.mediaSeekError,
        message: 'seek result:${seekResult.errorCode}',
        method: 'seekTo',
      ));
    }

    return seekResult;
  }

  /// Set media player volume. Both the local play volume and the publish volume are set.
  ///
  /// - [volume] The range is 0 ~ 100. The default is 30.
  Future<void> setMediaVolume(int volume) async {
    return ZegoUIKitCore.shared.setMediaVolume(volume);
  }

  int getMediaVolume() {
    return ZegoUIKitCore.shared.getMediaVolume();
  }

  Future<void> muteMediaLocal(bool mute) async {
    ZegoUIKitCore.shared.muteMediaLocal(mute);
  }

  ValueNotifier<bool> getMediaMuteNotifier() {
    return ZegoUIKitCore.shared.getMediaMuteNotifier();
  }

  ValueNotifier<int> getMediaVolumeNotifier() {
    return ZegoUIKitCore.shared.getMediaVolumeNotifier();
  }

  /// Get the total progress of your media resources, Returns Unit is millisecond.
  int getMediaTotalDuration() {
    return ZegoUIKitCore.shared.getMediaTotalDuration();
  }

  /// Get current playing progress.
  int getMediaCurrentProgress() {
    return ZegoUIKitCore.shared.getMediaCurrentProgress();
  }

  ValueNotifier<int> getMediaCurrentProgressNotifier() {
    return ZegoUIKitCore.shared.getMediaCurrentProgressNotifier();
  }

  MediaType getMediaType() {
    return ZegoUIKitCore.shared.getMediaType();
  }

  ValueNotifier<MediaType> getMediaTypeNotifier() {
    return ZegoUIKitCore.shared.getMediaTypeNotifier();
  }

  ValueNotifier<MediaPlayState> getMediaPlayStateNotifier() {
    return ZegoUIKitCore.shared.getMediaPlayStateNotifier();
  }

  Future<List<PlatformFile>> pickPureAudioMediaFile() async {
    return ZegoUIKitCore.shared.pickPureAudioMediaFile();
  }

  Future<List<PlatformFile>> pickVideoMediaFile() async {
    return ZegoUIKitCore.shared.pickVideoMediaFile();
  }

  Future<List<PlatformFile>> pickMediaFile() async {
    return ZegoUIKitCore.shared.pickMediaFile();
  }

  MediaInfo getMediaInfo() {
    return ZegoUIKitCore.shared.getMediaInfo();
  }
}
